Struct FixedSizeBlockAllocator

pub struct FixedSizeBlockAllocator { /* private fields */ }

Implementations

Source

impl FixedSizeBlockAllocator

pub const fn new() -> Self

Creates an empty FixedSizeBlockAllocator.

pub unsafe fn init(&mut self, heap_start: usize, heap_size: usize)

Initialize the allocator with the given heap bounds.

This function is unsafe because the caller must guarantee that the given heap bounds are valid and that the heap is unused. This method must be called only once.